% EVALUATESOLUTION  evaluates the hp-FEM solution on point values
%
% function [U,xplot,yplot] = evaluateSolution(x, y, p, u, xplot, yplot)
%
% INPUT
%   x,y    coordinates of the mesh nodes
%   p      polynomial degree
%   u      solution vector
%   xplot  evaluation points in x-direction
%   yplot  evaluation points in y-direction
%
% OUTPUT
%   U      solution on evaluation points
%   xplot  evaluation points where mesh nodes are included
%   yplot  evaluation points where mesh nodes are included

function [U,xplot,yplot] = evaluateSolution(x, y, p, u, xplot, yplot)

xplot = unique([x xplot]);
yplot = unique([y yplot]);
uplot = zeros(length(yplot),length(xplot));

% intervall lengthes
hx = diff(x); nx = length(hx);
hy = diff(y); ny = length(hy);

for i=1:nx
  Ix = find(xplot > x(i) & xplot <= x(i+1));
  if ~isempty(Ix)
    xi   = (xplot(Ix) - x(i))/hx(i)*2 - 1;
    for j=1:ny
      Iy = find(yplot > y(j) & yplot <= y(j+1));
      if ~isempty(Iy)
	eta   = (yplot(Iy) - y(j))/hy(i)*2 - 1;
	U(Iy, Ix) = evaluateCell(i, j, nx, ny, p, u, xi, eta);
      end
    end
  end
end

return;

