% SHAPEFCT1D  evaluates the 1D shape functions 
%
% function Nu = shapefct1D(p, xi)
%
% p    polynomial degree
% xi   1 x N array of evaluation points in [-1,1]
%
% Nu   (p+1) x N of shape function values

function Nu = shapefct1D(p, xi)

if xi(end) > 1, xi(end) = 1;end
for i=1:p+1
  L_     = legendre(i-1,xi);
  L(i,:) = L_(1,:);
end
Nu(1,:) = (1-xi)/2; Nu(2,:) = (1+xi)/2;
for i=3:p+1
  Nu(i,:) = (L(i,:) - L(i-2,:))/sqrt(2*(2*i-3));  
end
return;